==> eoaCommonWidget-1.0.1-20191202.024555-2-sources.jar: com/xdja/eoa/commonwidget/widget/refreshloading/CustomRefreshHeader.java <==
package com.xdja.eoa.commonwidget.widget.refreshloading;

import android.content.Context;
import android.graphics.drawable.AnimationDrawable;
import android.util.AttributeSet;
import android.widget.ImageView;
import com.xdja.eoa.commonwidget.R;

/**
 * Created by hjl on 2017/5/10.
 */

public class CustomRefreshHeader extends BaseRefreshHeader {

    private ImageView headPbar;
    private AnimationDrawable animationDrawable;

    public CustomRefreshHeader(Context context) {
        this(context,null);
    }

    public CustomRefreshHeader(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    @Override
    protected int getHeaderResId() {
        return R.layout.layout_list_refresh_header;
    }

    @Override
    protected void onPreReFresh() {
        if (animationDrawable.isRunning()){
            animationDrawable.stop();
        }
    }

    @Override
    protected void onRelease2ReFresh() {
        if(!animationDrawable.isRunning()){
            animationDrawable.start();
        }

    }

    @Override
    protected void onReFreshing() {
        if (!animationDrawable.isRunning()){
            animationDrawable.start();
        }
    }

    @Override
    protected void onReFreshDone() {
        if (animationDrawable.isRunning()){
            animationDrawable.stop();
        }
    }

    @Override
    protected void initView() {
        headPbar = findViewById(R.id.iv_head_pbar);
        animationDrawable = (AnimationDrawable) headPbar.getDrawable();
    }
}

==> eoaCommonWidget-2.0.0-sources.jar: com/xdja/eoa/commonwidget/widget/refreshloading/CustomRefreshHeader.java <==
package com.xdja.eoa.commonwidget.widget.refreshloading;

import android.content.Context;
import android.graphics.drawable.AnimationDrawable;
import android.util.AttributeSet;
import android.widget.ImageView;

/**
 * Created by hjl on 2017/5/10.
 */

public class CustomRefreshHeader extends BaseRefreshHeader {

    private ImageView headPbar;
    private AnimationDrawable animationDrawable;

    public CustomRefreshHeader(Context context) {
        this(context,null);
    }

    public CustomRefreshHeader(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    @Override
    protected int getHeaderResId() {
//        return R.layout.layout_list_refresh_header;
        return 0;
    }

    @Override
    protected void onPreReFresh() {
        if (animationDrawable.isRunning()){
            animationDrawable.stop();
        }
    }

    @Override
    protected void onRelease2ReFresh() {
        if(!animationDrawable.isRunning()){
            animationDrawable.start();
        }

    }

    @Override
    protected void onReFreshing() {
        if (!animationDrawable.isRunning()){
            animationDrawable.start();
        }
    }

    @Override
    protected void onReFreshDone() {
        if (animationDrawable.isRunning()){
            animationDrawable.stop();
        }
    }

    @Override
    protected void initView() {
//        headPbar = findViewById(R.id.iv_head_pbar);
        animationDrawable = (AnimationDrawable) headPbar.getDrawable();
    }
}
